@@ -21,6 +21,10 @@ pub enum ScriptCreationError {
     BadParameters,
     /// At least one of the keys was not derivable
     NonWildcardKeys,
+    /// No xpub were present in a generalist descriptor
+    NoXpub,
+    /// Invalid derived public key, must always be of the form '[fingerprint/index]<66 hex chars>'
+    DerivedKeyParsing,
     /// Miniscript policy compilation error
     PolicyCompilation(CompilerError),
     /// Miniscript general error, currently only for sanity checks in descriptor
@@ -35,6 +39,8 @@ impl fmt::Display for ScriptCreationError {
             Self::PolicyCompilation(e) => write!(f, "Policy compilation error: '{}'", e),
             Self::MiniscriptError(e) => write!(f, "Miniscript error: '{}'", e),
             Self::NonWildcardKeys => write!(f, "Not all xpubs were wildcard"),
+            Self::NoXpub => write!(f, "No xpub present in generalist descriptor"),
+            Self::DerivedKeyParsing => write!(f, "Invalid derived public key, must always be of the form '[fingerprint/index]<66 hex chars>'"),
         }
     }
 }
@@ -82,6 +88,8 @@ pub enum TransactionCreationError {
     NegativeFees,
     /// Transaction weight more than 400k weight units.
     TooLarge,
+    /// Trying to create a Spend transaction with the same prevout twice
+    DuplicatedInput,
 }
 
 impl fmt::Display for TransactionCreationError {
@@ -100,6 +108,10 @@ impl fmt::Display for TransactionCreationError {
                 f,
                 "Transaction too large: satisfied it could be >400k weight units"
             ),
+            Self::DuplicatedInput => write!(
+                f,
+                "Trying to create a Spend transaction with the same prevout twice"
+            ),
         }
     }
 }
